# Image

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | 
**name** | **str** |  | 
**description** | **str** |  | 
**display_name** | **str** |  | 
**platform** | **str** |  | 
**size_gib** | **int** |  | 
**installed_packages** | [**list[Package]**](Package.md) |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


